@@ -17,7 +17,7 @@
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 #  MA 02110-1301, USA.
 #
-#  version: 20220815135339
+#  version: 20220815140019
 
 from json import dumps
 import re
@@ -115,7 +115,7 @@ class InterceptorHandlerFactory:
                         .hum {float:left; font-size:12pt;}
                         .late { background-color:red; }
                         """
-                        html = f"""<html>
+                        html = bytes(f"""<html>
                         <head><meta charset="UTF-8"><meta http-equiv="refresh" content="300"><title>Temperatuur binnen</title>
                         <style>{style}</style>
                         </head>
@@ -126,7 +126,7 @@ class InterceptorHandlerFactory:
                         </body>
                         <script>document.querySelectorAll("[data-time]").forEach(function(e){{d=new Date(e.getAttribute("data-time"));e.innerHTML=d.getHours() + ":" + d.getMinutes().toString().padStart(2, '0')}})</script>
                         </html>
-                        """
+                        """, "UTF-8")
                         self.send_response(HTTPStatus.OK)
                         self.send_header("Content-type", "text/html")
                         self.send_header("Content-Length", str(len(html)))
